@@ -34,7 +34,7 @@
 #include <linux/dmi.h>
 #include <linux/ioport.h>
 #include <linux/delay.h>
-#include <linux/thinkpad_ec.h>
+#include "thinkpad_ec.h"
 #include <linux/jiffies.h>
 #include <asm/io.h>
 
@@ -45,7 +45,7 @@
 	#include <linux/semaphore.h>
 #endif
 
-#define TP_VERSION "0.40"
+#define TP_VERSION "0.42"
 
 MODULE_AUTHOR("Shem Multinymous");
 MODULE_DESCRIPTION("ThinkPad embedded controller hardware access");
@@ -88,10 +88,14 @@ static u64 prefetch_jiffies;                      /* time of prefetch, or: */
 #define TPC_PREFETCH_JUNK   (INITIAL_JIFFIES+1)   /*   Ignore prefetch */
 
 /* Locking: */
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,37)
 static DECLARE_MUTEX(thinkpad_ec_mutex);
+#else
+static DEFINE_SEMAPHORE(thinkpad_ec_mutex);
+#endif
 
 /* Kludge in case the ACPI DSDT reserves the ports we need. */
-static int force_io;    /* Willing to do IO to ports we couldn't reserve? */
+static bool force_io;    /* Willing to do IO to ports we couldn't reserve? */
 static int reserved_io; /* Successfully reserved the ports? */
 module_param_named(force_io, force_io, bool, 0600);
 MODULE_PARM_DESC(force_io, "Force IO even if region already reserved (0=off, 1=on)");
@@ -456,6 +460,7 @@ static int __init check_dmi_for_ec(void)
 		TP_DMI_MATCH("IBM", "ThinkPad A30"),
 		TP_DMI_MATCH("IBM", "ThinkPad T23"),
 		TP_DMI_MATCH("IBM", "ThinkPad X24"),
+		TP_DMI_MATCH("LENOVO", "ThinkPad"),
 		{ .ident = NULL }
 	};
 	return dmi_find_substring(DMI_DEV_TYPE_OEM_STRING,
